@@ -1,11 +1,11 @@
-# $Id: DOM.pm 5281 2007-06-27 19:37:45Z mnodine $
+# $Id: DOM.pm 6235 2010-03-01 20:23:51Z mnodine $
 # Copyright (C) 2002-2005 Freescale Semiconductor, Inc.
 # Distributed under terms of the Perl license, which is the disjunction of
 # the GNU General Public License (GPL) and the Artistic License.
 
 package Text::Restructured::DOM;
 
-($VERSION) = q$Revision: 5281 $ =~ /(\d+)/g;
+($VERSION) = q$Revision: 6235 $ =~ /(\d+)/g;
 
 # This package contains routines for Document Object Model (DOM) objects.
 # A DOM object is the prest equivalent of a doctree object.
@@ -60,12 +60,13 @@ sub newPCDATA {
 # INSTANCE METHOD.
 # Appends to the contents of a DOM object.
 # Arguments: DOM objects to append
-# Returns: The new number of contents
+# Returns: The DOM object
 sub append : method {
     my ($dom, @doms) = @_;
 
     @PARENT{@doms} = ($dom) x @doms;
     push @{$dom->{content}}, @doms;
+    return $dom;
 }
 
 # INSTANCE METHOD.
@@ -82,11 +83,25 @@ sub child : method {
 # Arguments: None
 # Returns: Array of content DOM objects
 sub contents : method {
-    my ($dom, @doms) = @_;
+    my ($dom) = @_;
 
     return @{$dom->{content}};
 }
 
+# INSTANCE METHOD.
+# Returns the first DOM in the contents of a DOM.
+# Arguments: None
+# Returns: first DOM object (or undefined)
+sub first : method {
+    my ($dom) = @_;
+
+    my $first;
+    if (@{$dom->{content}}) {
+	$first = $dom->{content}[0];
+    }
+    return $first;
+}
+
 # INSTANCE METHOD.
 # Returns the index of a child in the contents (-1 if it does not occur).
 # Arguments: child DOM object
@@ -293,12 +308,13 @@ sub substitute : method {
 
 # INSTANCE METHOD.
 # Returns the tag of a DOM object
-# Arguments: None
+# Arguments: Optional new tag value
 # Returns: Tag
 sub tag : method {
-    my($dom) = @_;
+    my($dom, $new_tag) = @_;
 
-    $dom->{tag};
+    $dom->{tag} = $new_tag if defined $new_tag;
+    return $dom->{tag};
 }
 
 # Parses text that is in DOM (pseudo-XML) format.
@@ -314,8 +330,7 @@ sub Parse {
     my $main;
     my @text = split /\n/, $text;
     foreach (@text) {
-	/(\s*).*/;
-	my $spaces = $1;
+	my ($spaces) = /^(\s*)/;
 	my $indent = length($spaces);
 	if (@stack > 0) {
 	    my $i;
@@ -414,7 +429,7 @@ my (%takes_body_elts, %takes_inline_elts, %is_body_elt, %is_inline_elt);
 # Returns: True if the DOM object can take body elements in its contents
 sub takes_body_elts : method {
     my ($dom) = @_;
-    return $takes_body_elts{$dom->tag};
+    return $takes_body_elts{$dom->tag} || 0;
 }
 
 # INSTANCE METHOD.
@@ -422,7 +437,7 @@ sub takes_body_elts : method {
 # Returns: True if the DOM object can take inline elements in its contents
 sub takes_inline_elts : method {
     my ($dom) = @_;
-    return $takes_inline_elts{$dom->tag};
+    return $takes_inline_elts{$dom->tag} || 0;
 }
 
 # INSTANCE METHOD.
@@ -430,7 +445,7 @@ sub takes_inline_elts : method {
 # Returns: True if the DOM object is a body element
 sub is_body_elt : method {
     my ($dom) = @_;
-    return $is_body_elt{$dom->tag};
+    return $is_body_elt{$dom->tag} || 0;
 }
 
 # INSTANCE METHOD.
@@ -438,7 +453,7 @@ sub is_body_elt : method {
 # Returns: True if the DOM object is an inline element
 sub is_inline_elt : method {
     my ($dom) = @_;
-    return $is_inline_elt{$dom->tag};
+    return $is_inline_elt{$dom->tag} || 0;
 }
 
 }
